package uca.baptistearthur.geocaching.ui.overlay

import android.os.AsyncTask
import android.util.Log
import android.view.MotionEvent
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import org.osmdroid.bonuspack.routing.Road
import org.osmdroid.bonuspack.routing.RoadManager
import org.osmdroid.util.GeoPoint
import org.osmdroid.views.MapView
import org.osmdroid.views.overlay.Overlay
import org.osmdroid.views.overlay.Polyline


class AddMarkerOverlay(val roadManager: RoadManager) : Overlay() {

    private var locations: MutableSet<GeoPoint> = mutableSetOf()
    private lateinit var roadOverlay: Polyline
    override fun onDoubleTap(e: MotionEvent?, mapView: MapView?): Boolean {
        Log.d("GeoMap", "Longpress")
        val proj = mapView?.projection;
        if(proj!=null){
            val loc = proj.fromPixels(e?.x?.toInt()!!, e.y.toInt() ) as GeoPoint
            locations.add(loc)
            val marker = PlaceMarker(mapView, locations, this)
            marker.position = loc
            marker.title = "Step " + locations.size
            mapView.overlays.add(marker)
            computeRoad(mapView)
        }
        return true;
    }

    fun computeRoad(mapView: MapView) {
        mapView.overlays.remove(mapView.overlays.find { it is Polyline})
        if (locations.size > 1) {
            CoroutineScope(Dispatchers.IO).launch {
                val road = roadManager.getRoad(ArrayList(locations))
                withContext(Dispatchers.Main) {
                    roadOverlay = RoadManager.buildRoadOverlay(road)
                    roadOverlay.width=10.0f;
                    mapView.overlays.add(roadOverlay)
                    mapView.invalidate()
                }
            }
        }
    }





}